AppLocalizationsIt class

The translations for Italian (it).

Inheritance

Constructors

AppLocalizationsIt([String locale = 'it'])

Properties

add_to → String
No description provided for @add_to.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
localeName → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited